summaryrefslogtreecommitdiff
path: root/libgo/go/internal/poll/fd_plan9.go
diff options
context:
space:
mode:
Diffstat (limited to 'libgo/go/internal/poll/fd_plan9.go')
-rw-r--r--libgo/go/internal/poll/fd_plan9.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/libgo/go/internal/poll/fd_plan9.go b/libgo/go/internal/poll/fd_plan9.go
index 107f4545233..0fce32915e7 100644
--- a/libgo/go/internal/poll/fd_plan9.go
+++ b/libgo/go/internal/poll/fd_plan9.go
@@ -193,10 +193,10 @@ func isInterrupted(err error) bool {
return err != nil && stringsHasSuffix(err.Error(), "interrupted")
}
-// PollDescriptor returns the descriptor being used by the poller,
-// or ^uintptr(0) if there isn't one. This is only used for testing.
-func PollDescriptor() uintptr {
- return ^uintptr(0)
+// IsPollDescriptor reports whether fd is the descriptor being used by the poller.
+// This is only used for testing.
+func IsPollDescriptor(fd uintptr) bool {
+ return false
}
// RawControl invokes the user-defined function f for a non-IO